#!/usr/bin/env bash
set -o errexit

defaultwineprefix="$HOME/.wine32_era"

show_help() {
  # 5. (Optional, and possibly unneeded) Add the locale: ja_JP.UTF-8 to your system, regenerate your locales.
  cat <<EOF

Usage: ${0##*/} [-h | -i | -f | -r | -d]

All options use the following default WINEPREFIX=$defaultwineprefix
but you will respect your own (your current WINEPREFIX is $prefix).

-h  Display this help and exit
-i  Prepare a wineprefix for emuera games
-f  Run winetricks emuera.verb to install umefonts
-r  Run "Emuera-Anchor.exe" through wine
-d  Run "Emuera-Anchor.exe -debug" through wine

This is an hoverview about how to run this game on linux, follow the instructions if you want.
In the end you will need a wine with dotnet40 or dotnet45 and the MS Gothic/umefonts font in it.

General Setup:
1. Install wine and winetricks using your package manager.
2. Run the following:
   WINEARCH=win32 WINEPREFIX=$defaultwineprefix wine wineboot
   WINEPREFIX=$defaultwineprefix winetricks dotnet40

Fonts:
3.
   Option a, MS Gothic:
     If you have a windows machine get the MS Gothic font, it's Windows/Fonts/msgothic.ttc
     Copy the font into your wine prefix folder in $defaultwineprefix/drive_c/windows/Fonts
   Option b, umefonts:
     Use WINEPREFIX=$defaultwineprefix winetrics ./emuera.verb
     or
     $0 -f

4. Finally run Emuera-Anchor with
     WINEPREFIX=$defaultwineprefix wine ./Emuera-Anchor.exe
     or
     $0 -r

Troubleshooting:
- Dotnet install hangs.
  Are you in a ssh session? You need a DISPLAY, do XForwarding or use xpra.
  Check for error messages, ensure you have required libraries for wine.
  Kill everything wine related and try again.
- Emuera does not open.
  Check for error messages.
  Reinstall dotnet40.
  Kill everything wine related and try again.
  Do a clean wine prefix install.
- Emuera opens but it's full of □ squares.
  Check if Emuera font settings, in Help/Settings, show ＭＳ ゴシック.
  Does your wine prefix contains msgothic.ttc or the ume-*.ttf?
  Check that Emuera display settings, in Help/Settings, are correct. Delete emuera.config. Restart Emuera.
  Does WINEPREFIX=$defaultwineprefix winetrics -f ./emuera.verb solve it?
  Do a clean wine prefix install.
- Fucking thing was working before, now does not.
  Kill everything wine related and try again.
  Do a clean wine prefix install.

EOF
}

get_font() {
  if [ ! -f "$prefix/drive_c/windows/Fonts/msgothic.ttc" ]; then
    echo Info: MS Gothic font not found in "$prefix"/drive_c/windows/Fonts/msgothic.ttc
    read -r -e -p "Do you want to use umefont? [y/N] " YN

    [[ $YN == "y" || $YN == "Y" ]] &&
      WINEPREFIX=$prefix winetricks ./emuera.verb
  else
    echo Info: MS Gothic font present.
    echo Exiting.
  fi
}

run() {
  if [ ! -d "$prefix" ]; then
    echo Error: Directory "$prefix" not found.
    exit 1
  else
    WINEPREFIX="$prefix" wine ./Emuera-Anchor.exe"$DEBUG"
  fi
}

prepare_wineprefix() {
  read -r -e -p "Use the following WINEPREFIX=$prefix ? [y/N] " YN

  (
    [[ $YN == "y" || $YN == "Y" ]] &&
      WINEDLLOVERRIDES='mscoree=d;mshtml=d' WINEARCH=win32 WINEPREFIX=$prefix wine wineboot &&
      WINEPREFIX=$prefix winetricks --unattended dotnet40 &&
      printf "\nWineprefix is ready, now copy your msgothic.ttc into %s/drive_c/windows/Fonts/.
If you already did run $0 -r \n" "$prefix"
  ) ||
    echo Exiting.
}

prefix="${WINEPREFIX:=$defaultwineprefix}"

OPTIND=1
DEBUG=''
while getopts "hifrd" opt; do
  case "$opt" in
    h)
      show_help
      exit 0
      ;;
    i)
      prepare_wineprefix
      exit 0
      ;;
    f)
      get_font
      exit 0
      ;;
    r)
      run
      ;;
    d)
      DEBUG=' -debug'
      run
      ;;
    \?)
      printf "\n"
      show_help
      exit 1
      ;;
  esac
done
if [ $OPTIND -eq 1 ]; then show_help; fi
shift "$((OPTIND - 1))"
